@@ -325,13 +325,21 @@ class LoadMaster(HttpClient):
                 virt_serv.real_servers.append(rs)
             virtual_services.append(virt_serv)
         # replace subvs's with vs's that have RSs in them.
+        """
         for vs in virtual_services:
             vs.subvs_entries = []
+            print(vs.subvs_entries)
             parent_vs_id = vs.mastervsid
             if parent_vs_id != 0:
                 for parent_vs in virtual_services:
                     if parent_vs.index == parent_vs_id:
                         parent_vs.subvs_entries.append(vs)
+        """
+        for vs in virtual_services:
+            for subvs in vs.subvs_entries:
+                for top_level_vs in virtual_services:
+                    if subvs.index == top_level_vs.index:
+                        subvs.real_servers = top_level_vs.real_servers
 
         return virtual_services
 
