@@ -183,3 +183,10 @@ class UserAlreadyExistsException(KempTechApiException):
                .format(user, ip_address))
         super(UserAlreadyExistsException, self).__init__(msg, code=code,
                                                          is_xml_msg=False)
+
+
+class NotVirtualServiceInstanceError(KempTechApiException):
+    def __init__(self, code=None):
+        msg = ("The object you are trying to clone is "
+               "not an instance of VirtualService.")
+        super(NotVirtualServiceInstanceError, self).__init__(msg, code=code)
